@@ -4,7 +4,7 @@
     Description          : Aspect that manages a column
     --------------------------------------------------------------------
     Copyright            : (C) 2007-2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2013-2015 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2013-2017 by Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -34,10 +34,26 @@
 #include "backend/core/datatypes/String2DateTimeFilter.h"
 #include "backend/core/datatypes/DateTime2StringFilter.h"
 
-#include <QMetaEnum>
+extern "C" {
+#include <gsl/gsl_sort.h>
+}
+
+#include <QFont>
+#include <QFontMetrics>
 #include <QThreadPool>
 #include <QIcon>
 #include <KLocale>
+#include <QThreadPool>
+#ifndef NDEBUG
+#include <QDebug>
+#endif
+
+#include <KIcon>
+#include <KLocale>
+
+extern "C" {
+#include <gsl/gsl_sort.h>
+}
 
 /**
  * \class Column
@@ -62,8 +78,7 @@
  * \param mode initial column mode
  */
 Column::Column(const QString& name, AbstractColumn::ColumnMode mode)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, mode) )
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, mode) ) {
 	init();
 }
 
@@ -74,8 +89,7 @@ Column::Column(const QString& name, AbstractColumn::ColumnMode mode)
  * \param data initial data vector
  */
 Column::Column(const QString& name, QVector<double> data)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Numeric, new QVector<double>(data)) )
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Numeric, new QVector<double>(data)) ) {
 	init();
 }
 
@@ -86,8 +100,7 @@ Column::Column(const QString& name, QVector<double> data)
  * \param data initial data vector
  */
 Column::Column(const QString& name, QStringList data)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Text, new QStringList(data)))
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Text, new QStringList(data))) {
 	init();
 }
 
@@ -98,8 +111,7 @@ Column::Column(const QString& name, QStringList data)
  * \param data initial data vector
  */
 Column::Column(const QString& name, QList<QDateTime> data)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::DateTime, new QList<QDateTime>(data)) )
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::DateTime, new QList<QDateTime>(data)) ) {
 	init();
 }
 
@@ -114,8 +126,6 @@ void Column::init() {
 	m_column_private->outputFilter()->setHidden(true);
 	addChild(m_column_private->inputFilter());
 	addChild(m_column_private->outputFilter());
-	m_column_private->setWidth(120);
-
 	m_suppressDataChangedSignal = false;
 }
 
@@ -140,21 +150,18 @@ void Column::setSuppressDataChangedSignal(bool b) {
  * This sets the column mode and, if
  * necessary, converts it to another datatype.
  */
-void Column::setColumnMode(AbstractColumn::ColumnMode mode)
-{
+void Column::setColumnMode(AbstractColumn::ColumnMode mode) {
 	if(mode == columnMode()) return;
 	beginMacro(i18n("%1: change column type", name()));
 	AbstractSimpleFilter * old_input_filter = m_column_private->inputFilter();
 	AbstractSimpleFilter * old_output_filter = m_column_private->outputFilter();
 	exec(new ColumnSetModeCmd(m_column_private, mode));
-	if (m_column_private->inputFilter() != old_input_filter)
-	{
+	if (m_column_private->inputFilter() != old_input_filter) {
 		removeChild(old_input_filter);
 		addChild(m_column_private->inputFilter());
 		m_column_private->inputFilter()->input(0,m_string_io);
 	}
-	if (m_column_private->outputFilter() != old_output_filter)
-	{
+	if (m_column_private->outputFilter() != old_output_filter) {
 		removeChild(old_output_filter);
 		addChild(m_column_private->outputFilter());
 		m_column_private->outputFilter()->input(0, this);
@@ -162,7 +169,6 @@ void Column::setColumnMode(AbstractColumn::ColumnMode mode)
 	endMacro();
 }
 
-
 /**
  * \brief Copy another column of the same type
  *
@@ -170,8 +176,7 @@ void Column::setColumnMode(AbstractColumn::ColumnMode mode)
  * of 'other' is not the same as the type of 'this'.
  * Use a filter to convert a column to another type.
  */
-bool Column::copy(const AbstractColumn * other)
-{
+bool Column::copy(const AbstractColumn * other) {
 	Q_CHECK_PTR(other);
 	if(other->columnMode() != columnMode()) return false;
 	exec(new ColumnFullCopyCmd(m_column_private, other));
@@ -188,8 +193,7 @@ bool Column::copy(const AbstractColumn * other)
  * \param dest_start first row to copy in
  * \param num_rows the number of rows to copy
  */
-bool Column::copy(const AbstractColumn * source, int source_start, int dest_start, int num_rows)
-{
+bool Column::copy(const AbstractColumn * source, int source_start, int dest_start, int num_rows) {
 	Q_CHECK_PTR(source);
 	if(source->columnMode() != columnMode()) return false;
 	exec(new ColumnPartialCopyCmd(m_column_private, source, source_start, dest_start, num_rows));
@@ -199,30 +203,31 @@ bool Column::copy(const AbstractColumn * source, int source_start, int dest_star
 /**
  * \brief Insert some empty (or initialized with zero) rows
  */
-void Column::handleRowInsertion(int before, int count)
-{
+void Column::handleRowInsertion(int before, int count) {
 	AbstractColumn::handleRowInsertion(before, count);
 	exec(new ColumnInsertRowsCmd(m_column_private, before, count));
 	if (!m_suppressDataChangedSignal)
 		emit dataChanged(this);
+
+	setStatisticsAvailable(false);
 }
 
 /**
  * \brief Remove 'count' rows starting from row 'first'
  */
-void Column::handleRowRemoval(int first, int count)
-{
+void Column::handleRowRemoval(int first, int count) {
 	AbstractColumn::handleRowRemoval(first, count);
 	exec(new ColumnRemoveRowsCmd(m_column_private, first, count));
 	if (!m_suppressDataChangedSignal)
 		emit dataChanged(this);
+
+	setStatisticsAvailable(false);
 }
 
 /**
  * \brief Set the column plot designation
  */
-void Column::setPlotDesignation(AbstractColumn::PlotDesignation pd)
-{
+void Column::setPlotDesignation(AbstractColumn::PlotDesignation pd) {
 	if(pd != plotDesignation())
 		exec(new ColumnSetPlotDesignationCmd(m_column_private, pd));
 }
@@ -230,25 +235,21 @@ void Column::setPlotDesignation(AbstractColumn::PlotDesignation pd)
 /**
  * \brief Get width
  */
-int Column::width() const
-{
+int Column::width() const {
 	return m_column_private->width();
 }
 
 /**
  * \brief Set width
  */
-void Column::setWidth(int value)
-{
-	if (value != m_column_private->width())
-		exec(new ColumnSetWidthCmd(m_column_private, value));
+void Column::setWidth(int value) {
+	m_column_private->setWidth(value);
 }
 
 /**
  * \brief Clear the whole column
  */
-void Column::clear()
-{
+void Column::clear() {
 	exec(new ColumnClearCmd(m_column_private));
 }
 
@@ -285,24 +286,21 @@ void Column::setFormula(const QString& formula, const QStringList& variableNames
 /**
  * \brief Set a formula string for an interval of rows
  */
-void Column::setFormula(Interval<int> i, QString formula)
-{
+void Column::setFormula(Interval<int> i, QString formula) {
 	exec(new ColumnSetFormulaCmd(m_column_private, i, formula));
 }
 
 /**
  * \brief Overloaded function for convenience
  */
-void Column::setFormula(int row, QString formula)
-{
+void Column::setFormula(int row, QString formula) {
 	setFormula(Interval<int>(row, row), formula);
 }
 
 /**
  * \brief Clear all formulas
  */
-void Column::clearFormulas()
-{
+void Column::clearFormulas() {
 	exec(new ColumnClearFormulasCmd(m_column_private));
 }
 
@@ -320,8 +318,8 @@ void Column::clearFormulas()
  *
  * Use this only when columnMode() is Text
  */
-void Column::setTextAt(int row, const QString& new_value)
-{
+void Column::setTextAt(int row, const QString& new_value) {
+	setStatisticsAvailable(false);
 	exec(new ColumnSetTextCmd(m_column_private, row, new_value));
 }
 
@@ -330,10 +328,11 @@ void Column::setTextAt(int row, const QString& new_value)
  *
  * Use this only when columnMode() is Text
  */
-void Column::replaceTexts(int first, const QStringList& new_values)
-{
-	if (!new_values.isEmpty())
+void Column::replaceTexts(int first, const QStringList& new_values) {
+	if (!new_values.isEmpty()) { //TODO: do we really need this check?
+		setStatisticsAvailable(false);
 		exec(new ColumnReplaceTextsCmd(m_column_private, first, new_values));
+	}
 }
 
 /**
@@ -341,8 +340,8 @@ void Column::replaceTexts(int first, const QStringList& new_values)
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::setDateAt(int row, const QDate& new_value)
-{
+void Column::setDateAt(int row, const QDate& new_value) {
+	setStatisticsAvailable(false);
 	setDateTimeAt(row, QDateTime(new_value, timeAt(row)));
 }
 
@@ -351,8 +350,8 @@ void Column::setDateAt(int row, const QDate& new_value)
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::setTimeAt(int row,const QTime& new_value)
-{
+void Column::setTimeAt(int row,const QTime& new_value) {
+	setStatisticsAvailable(false);
 	setDateTimeAt(row, QDateTime(dateAt(row), new_value));
 }
 
@@ -361,8 +360,8 @@ void Column::setTimeAt(int row,const QTime& new_value)
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::setDateTimeAt(int row, const QDateTime& new_value)
-{
+void Column::setDateTimeAt(int row, const QDateTime& new_value) {
+	setStatisticsAvailable(false);
 	exec(new ColumnSetDateTimeCmd(m_column_private, row, new_value));
 }
 
@@ -371,10 +370,11 @@ void Column::setDateTimeAt(int row, const QDateTime& new_value)
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::replaceDateTimes(int first, const QList<QDateTime>& new_values)
-{
-	if (!new_values.isEmpty())
+void Column::replaceDateTimes(int first, const QList<QDateTime>& new_values) {
+	if (!new_values.isEmpty()) {
+		setStatisticsAvailable(false);
 		exec(new ColumnReplaceDateTimesCmd(m_column_private, first, new_values));
+	}
 }
 
 /**
@@ -382,8 +382,8 @@ void Column::replaceDateTimes(int first, const QList<QDateTime>& new_values)
  *
  * Use this only when columnMode() is Numeric
  */
-void Column::setValueAt(int row, double new_value)
-{
+void Column::setValueAt(int row, double new_value) {
+	setStatisticsAvailable(false);
 	exec(new ColumnSetValueCmd(m_column_private, row, new_value));
 }
 
@@ -392,13 +392,134 @@ void Column::setValueAt(int row, double new_value)
  *
  * Use this only when columnMode() is Numeric
  */
-void Column::replaceValues(int first, const QVector<double>& new_values)
-{
-	if (!new_values.isEmpty())
+void Column::replaceValues(int first, const QVector<double>& new_values) {
+	if (!new_values.isEmpty()) {
+		setStatisticsAvailable(false);
 		exec(new ColumnReplaceValuesCmd(m_column_private, first, new_values));
+	}
 }
 
-void* Column::data() const{
+void Column::setStatisticsAvailable(bool available) {
+	m_column_private->statisticsAvailable = available;
+}
+
+bool Column::statisticsAvailable() const {
+	return m_column_private->statisticsAvailable;
+}
+
+
+const Column::ColumnStatistics& Column::statistics() {
+	if (!statisticsAvailable())
+		calculateStatistics();
+
+	return m_column_private->statistics;
+}
+
+void Column::calculateStatistics() {
+	m_column_private->statistics = ColumnStatistics();
+	ColumnStatistics& statistics = m_column_private->statistics;
+
+	QVector<double>* rowValues = reinterpret_cast<QVector<double>*>(data());
+
+	int notNanCount = 0;
+	double val;
+	double columnSum = 0.0;
+	double columnProduct = 1.0;
+	double columnSumNeg = 0.0;
+	double columnSumSquare = 0.0;
+	statistics.minimum = INFINITY;
+	statistics.maximum = -INFINITY;
+	QMap<double, int> frequencyOfValues;
+	QVector<double> rowData;
+	rowData.reserve(rowValues->size());
+	for (int row = 0; row < rowValues->size(); ++row) {
+		val = rowValues->value(row);
+		if (std::isnan(val) || isMasked(row))
+			continue;
+
+		if (val < statistics.minimum)
+			statistics.minimum = val;
+		if (val > statistics.maximum)
+			statistics.maximum = val;
+		columnSum+= val;
+		columnSumNeg += (1.0 / val);
+		columnSumSquare += pow(val, 2.0);
+		columnProduct *= val;
+		if (frequencyOfValues.contains(val))
+			frequencyOfValues.operator [](val)++;
+		else
+			frequencyOfValues.insert(val, 1);
+		++notNanCount;
+		rowData.push_back(val);
+	}
+
+	if (notNanCount == 0) {
+		setStatisticsAvailable(true);
+		return;
+	}
+
+	if (rowData.size() < rowValues->size())
+		rowData.squeeze();
+
+	statistics.arithmeticMean = columnSum / notNanCount;
+	statistics.geometricMean = pow(columnProduct, 1.0 / notNanCount);
+	statistics.harmonicMean = notNanCount / columnSumNeg;
+	statistics.contraharmonicMean = columnSumSquare / columnSum;
+
+	double columnSumVariance = 0;
+	double columnSumMeanDeviation = 0.0;
+	double columnSumMedianDeviation = 0.0;
+	double sumForCentralMoment_r3 = 0.0;
+	double sumForCentralMoment_r4 = 0.0;
+
+	gsl_sort(rowData.data(), 1, notNanCount);
+	statistics.median = (notNanCount%2) ? rowData.at((notNanCount-1)/2) :
+	                    (rowData.at((notNanCount-1)/2) + rowData.at(notNanCount/2))/2.0;
+	QVector<double> absoluteMedianList;
+	absoluteMedianList.reserve(notNanCount);
+	absoluteMedianList.resize(notNanCount);
+
+	int idx = 0;
+	for(int row = 0; row < rowValues->size(); ++row) {
+		val = rowValues->value(row);
+		if ( std::isnan(val) || isMasked(row) )
+			continue;
+		columnSumVariance+= pow(val - statistics.arithmeticMean, 2.0);
+
+		sumForCentralMoment_r3 += pow(val - statistics.arithmeticMean, 3.0);
+		sumForCentralMoment_r4 += pow(val - statistics.arithmeticMean, 4.0);
+		columnSumMeanDeviation += fabs( val - statistics.arithmeticMean );
+
+		absoluteMedianList[idx] = fabs(val - statistics.median);
+		columnSumMedianDeviation += absoluteMedianList[idx];
+		idx++;
+	}
+
+	statistics.meanDeviationAroundMedian = columnSumMedianDeviation / notNanCount;
+	statistics.medianDeviation = (notNanCount%2) ? absoluteMedianList.at((notNanCount-1)/2) :
+	                             (absoluteMedianList.at((notNanCount-1)/2) + absoluteMedianList.at(notNanCount/2))/2.0;
+
+	const double centralMoment_r3 = sumForCentralMoment_r3 / notNanCount;
+	const double centralMoment_r4 = sumForCentralMoment_r4 / notNanCount;
+
+	statistics.variance = columnSumVariance / notNanCount;
+	statistics.standardDeviation = sqrt(statistics.variance);
+	statistics.skewness = centralMoment_r3 / pow(statistics.standardDeviation, 3.0);
+	statistics.kurtosis = (centralMoment_r4 / pow(statistics.standardDeviation, 4.0)) - 3.0;
+	statistics.meanDeviation = columnSumMeanDeviation / notNanCount;
+
+	double entropy = 0.0;
+	QList<int> frequencyOfValuesValues = frequencyOfValues.values();
+	for (int i = 0; i < frequencyOfValuesValues.size(); ++i) {
+		double frequencyNorm = static_cast<double>(frequencyOfValuesValues.at(i)) / notNanCount;
+		entropy += (frequencyNorm * log2(frequencyNorm));
+	}
+
+	statistics.entropy = -entropy;
+	setStatisticsAvailable(true);
+}
+
+void* Column::data() const {
 	return m_column_private->dataPointer();
 }
 /**
@@ -406,8 +527,7 @@ void* Column::data() const{
  *
  * Use this only when columnMode() is Text
  */
-QString Column::textAt(int row) const
-{
+QString Column::textAt(int row) const {
 	return m_column_private->textAt(row);
 }
 
@@ -416,8 +536,7 @@ QString Column::textAt(int row) const
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QDate Column::dateAt(int row) const
-{
+QDate Column::dateAt(int row) const {
 	return m_column_private->dateAt(row);
 }
 
@@ -426,8 +545,7 @@ QDate Column::dateAt(int row) const
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QTime Column::timeAt(int row) const
-{
+QTime Column::timeAt(int row) const {
 	return m_column_private->timeAt(row);
 }
 
@@ -436,16 +554,14 @@ QTime Column::timeAt(int row) const
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QDateTime Column::dateTimeAt(int row) const
-{
+QDateTime Column::dateTimeAt(int row) const {
 	return m_column_private->dateTimeAt(row);
 }
 
 /**
  * \brief Return the double value in row 'row'
  */
-double Column::valueAt(int row) const
-{
+double Column::valueAt(int row) const {
 	return m_column_private->valueAt(row);
 }
 
@@ -457,6 +573,8 @@ double Column::valueAt(int row) const
 void Column::setChanged() {
 	if (!m_suppressDataChangedSignal)
 		emit dataChanged(this);
+
+	setStatisticsAvailable(false);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -467,19 +585,17 @@ void Column::setChanged() {
  * \brief Return an icon to be used for decorating the views and spreadsheet column headers
  */
 QIcon Column::icon() const {
-	//TODO: provide type-specific icons
-// 	switch(columnMode()) {
-// 		case AbstractColumn::Numeric:
-// 			return KIcon("x-shape-text");
-// 		case AbstractColumn::Text:
-// 			return QIcon::fromTheme(QPixmap(":/texttype.png"));
-// 		case AbstractColumn::DateTime:
-// 		case AbstractColumn::Month:
-// 		case AbstractColumn::Day:
-// 			return QIcon::fromTheme(QPixmap(""));
-// 	}
-
-    return QIcon::fromTheme("x-shape-text");
+	switch(columnMode()) {
+	case AbstractColumn::Numeric:
+		return QIcon::fromTheme("x-shape-text");
+	case AbstractColumn::Text:
+		return QIcon::fromTheme("draw-text");
+	case AbstractColumn::DateTime:
+	case AbstractColumn::Month:
+	case AbstractColumn::Day:
+		return QIcon::fromTheme("chronometer");
+	}
+	return QIcon::fromTheme("x-shape-text");
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -494,8 +610,7 @@ void Column::save(QXmlStreamWriter* writer) const {
 	writer->writeStartElement("column");
 	writeBasicAttributes(writer);
 
-	writer->writeAttribute("mode", enumValueToString(columnMode(), "ColumnMode"));
-	writer->writeAttribute("plot_designation", enumValueToString(plotDesignation(), "PlotDesignation"));
+	writer->writeAttribute("mode", QString::number(columnMode()));
 	writer->writeAttribute("width", QString::number(width()));
 
 	//save the formula used to generate column values, if available
@@ -504,15 +619,13 @@ void Column::save(QXmlStreamWriter* writer) const {
 		writer->writeTextElement("text", formula());
 
 		writer->writeStartElement("variableNames");
-		for (int i=0; i<formulaVariableNames().size(); ++i) {
+		for (int i=0; i<formulaVariableNames().size(); ++i)
 			writer->writeTextElement("name", formulaVariableNames().at(i));
-		}
 		writer->writeEndElement();
 
 		writer->writeStartElement("columnPathes");
-		for (int i=0; i<formulaVariableColumnPathes().size(); ++i) {
+		for (int i=0; i<formulaVariableColumnPathes().size(); ++i)
 			writer->writeTextElement("path", formulaVariableColumnPathes().at(i));
-		}
 		writer->writeEndElement();
 
 		writer->writeEndElement();
@@ -541,54 +654,53 @@ void Column::save(QXmlStreamWriter* writer) const {
 
 	int i;
 	switch(columnMode()) {
-		case AbstractColumn::Numeric:
-			{
-				const char* data = reinterpret_cast<const char*>(
-				static_cast< QVector<double>* >(m_column_private->dataPointer())->constData());
-				int size = m_column_private->rowCount()*sizeof(double);
-				writer->writeCharacters(QByteArray::fromRawData(data,size).toBase64());
-				break;
-			}
-		case AbstractColumn::Text:
-			for(i=0; i<rowCount(); ++i)
-			{
-				writer->writeStartElement("row");
-				writer->writeAttribute("index", QString::number(i));
-				writer->writeCharacters(textAt(i));
-				writer->writeEndElement();
-			}
+	case AbstractColumn::Numeric: {
+			const char* data = reinterpret_cast<const char*>(
+			                       static_cast< QVector<double>* >(m_column_private->dataPointer())->constData());
+			int size = m_column_private->rowCount()*sizeof(double);
+			writer->writeCharacters(QByteArray::fromRawData(data,size).toBase64());
 			break;
+		}
+	case AbstractColumn::Text:
+		for(i=0; i<rowCount(); ++i) {
+			writer->writeStartElement("row");
+			writer->writeAttribute("index", QString::number(i));
+			writer->writeCharacters(textAt(i));
+			writer->writeEndElement();
+		}
+		break;
 
-		case AbstractColumn::DateTime:
-		case AbstractColumn::Month:
-		case AbstractColumn::Day:
-			for(i=0; i<rowCount(); ++i)
-			{
-				writer->writeStartElement("row");
-				writer->writeAttribute("index", QString::number(i));
-				writer->writeCharacters(dateTimeAt(i).toString("yyyy-dd-MM hh:mm:ss:zzz"));
-				writer->writeEndElement();
-			}
-			break;
+	case AbstractColumn::DateTime:
+	case AbstractColumn::Month:
+	case AbstractColumn::Day:
+		for(i=0; i<rowCount(); ++i) {
+			writer->writeStartElement("row");
+			writer->writeAttribute("index", QString::number(i));
+			writer->writeCharacters(dateTimeAt(i).toString("yyyy-dd-MM hh:mm:ss:zzz"));
+			writer->writeEndElement();
+		}
+		break;
 	}
 
 	writer->writeEndElement(); // "column"
 }
 
-
 class DecodeColumnTask : public QRunnable {
-	public:
-		DecodeColumnTask(ColumnPrivate* priv, const QString& content) { m_private =priv; m_content = content;};
-		void run() {
-			QByteArray bytes = QByteArray::fromBase64(m_content.toAscii());
-			QVector<double> * data = new QVector<double>(bytes.size()/sizeof(double));
-			memcpy(data->data(), bytes.data(), (bytes.size()/sizeof(double))*sizeof(double));
-			m_private->replaceData(data);
-		}
+public:
+	DecodeColumnTask(ColumnPrivate* priv, const QString& content) {
+		m_private = priv;
+		m_content = content;
+	};
+	void run() {
+		QByteArray bytes = QByteArray::fromBase64(m_content.toAscii());
+		QVector<double> * data = new QVector<double>(bytes.size()/sizeof(double));
+		memcpy(data->data(), bytes.data(), bytes.size());
+		m_private->replaceData(data);
+	}
 
-	private:
-		ColumnPrivate* m_private;
-		QString m_content;
+private:
+	ColumnPrivate* m_private;
+	QString m_content;
 };
 
 /**
@@ -596,53 +708,23 @@ class DecodeColumnTask : public QRunnable {
  */
 bool Column::load(XmlStreamReader* reader) {
 	if(reader->isStartElement() && reader->name() == "column") {
-		if (!readBasicAttributes(reader)) return false;
+		if (!readBasicAttributes(reader))
+			return false;
 
+		QString attributeWarning = i18n("Attribute '%1' missing or empty, default value is used");
 		QXmlStreamAttributes attribs = reader->attributes();
-		QString str;
 
-		// read mode
-		str = attribs.value(reader->namespaceUri().toString(), "mode").toString();
-		if(str.isEmpty()) {
-			reader->raiseError(i18n("column mode missing"));
-			return false;
-		}
+		QString str = attribs.value("mode").toString();
+		if(str.isEmpty())
+			reader->raiseWarning(attributeWarning.arg("'mode'"));
+		else
+			setColumnMode( AbstractColumn::ColumnMode(str.toInt()) );
 
-		int mode_code = enumStringToValue(str, "ColumnMode");
-		if(mode_code == -1) {
-			reader->raiseError(i18n("column mode invalid"));
-			return false;
-		}
-		AbstractColumn::ColumnMode mode = (AbstractColumn::ColumnMode)mode_code;
-		if (mode!=columnMode())
-			setColumnMode((AbstractColumn::ColumnMode)mode_code);
-
-		// read plot designation
-		str = attribs.value(reader->namespaceUri().toString(), "plot_designation").toString();
-		int pd_code = enumStringToValue(str, "PlotDesignation");
-		if(str.isEmpty()) {
-			setPlotDesignation(AbstractColumn::noDesignation);
-		} else if(pd_code == -1) {
-			reader->raiseError(i18n("column plot designation invalid"));
-			return false;
-		} else {
-			setPlotDesignation((AbstractColumn::PlotDesignation)pd_code);
-		}
-
-		bool ok;
-		int width = attribs.value(reader->namespaceUri().toString(), "width").toString().toInt(&ok);
-		if (ok)
-			setWidth(width);
-		else {
-			reader->raiseError(i18n("missing or invalid column width"));
-			return false;
-		}
-
-// 		setComment("");
-// 		if (rowCount() > 0)
-// 			removeRows(0, rowCount());
-// 		clearMasks();
-// 		clearFormulas();
+		str = attribs.value("width").toString();
+		if(str.isEmpty())
+			reader->raiseWarning(attributeWarning.arg("'width'"));
+		else
+			setWidth(str.toInt());
 
 		// read child elements
 		while (!reader->atEnd()) {
@@ -664,8 +746,7 @@ bool Column::load(XmlStreamReader* reader) {
 					ret_val = XmlReadFormula(reader);
 				else if(reader->name() == "row")
 					ret_val = XmlReadRow(reader);
-				else // unknown element
-				{
+				else { // unknown element
 					reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
 					if (!reader->skipToEndElement()) return false;
 				}
@@ -678,8 +759,7 @@ bool Column::load(XmlStreamReader* reader) {
 				QThreadPool::globalInstance()->start(task);
 			}
 		}
-	}
-	else // no column element
+	} else // no column element
 		reader->raiseError(i18n("no column element found"));
 
 	return !reader->error();
@@ -688,8 +768,7 @@ bool Column::load(XmlStreamReader* reader) {
 /**
  * \brief Read XML input filter element
  */
-bool Column::XmlReadInputFilter(XmlStreamReader * reader)
-{
+bool Column::XmlReadInputFilter(XmlStreamReader * reader) {
 	Q_ASSERT(reader->isStartElement() && reader->name() == "input_filter");
 	if (!reader->skipToNextTag()) return false;
 	if (!m_column_private->inputFilter()->load(reader)) return false;
@@ -701,8 +780,7 @@ bool Column::XmlReadInputFilter(XmlStreamReader * reader)
 /**
  * \brief Read XML output filter element
  */
-bool Column::XmlReadOutputFilter(XmlStreamReader * reader)
-{
+bool Column::XmlReadOutputFilter(XmlStreamReader * reader) {
 	Q_ASSERT(reader->isStartElement() && reader->name() == "output_filter");
 	if (!reader->skipToNextTag()) return false;
 	if (!m_column_private->outputFilter()->load(reader)) return false;
@@ -721,9 +799,9 @@ bool Column::XmlReadFormula(XmlStreamReader* reader) {
 	while (reader->readNext()) {
 		if (reader->isEndElement()) break;
 
-		if (reader->name() == "text") {
+		if (reader->name() == "text")
 			formula = reader->readElementText();
-		} else if (reader->name() == "variableNames") {
+		else if (reader->name() == "variableNames") {
 			while (reader->readNext()) {
 				if (reader->name() == "variableNames" && reader->isEndElement()) break;
 
@@ -767,8 +845,7 @@ bool Column::XmlReadFormula(XmlStreamReader* reader) {
 /**
  * \brief Read XML row element
  */
-bool Column::XmlReadRow(XmlStreamReader * reader)
-{
+bool Column::XmlReadRow(XmlStreamReader * reader) {
 	Q_ASSERT(reader->isStartElement() && reader->name() == "row");
 
 	QString str;
@@ -784,26 +861,25 @@ bool Column::XmlReadRow(XmlStreamReader * reader)
 
 	str = reader->readElementText();
 	switch(columnMode()) {
-		case AbstractColumn::Numeric:
-			{
-				double value = str.toDouble(&ok);
-				if(!ok) {
-					reader->raiseError(i18n("invalid row value"));
-					return false;
-				}
-				setValueAt(index, value);
-				break;
+	case AbstractColumn::Numeric: {
+			double value = str.toDouble(&ok);
+			if(!ok) {
+				reader->raiseError(i18n("invalid row value"));
+				return false;
 			}
-		case AbstractColumn::Text:
-			setTextAt(index, str);
+			setValueAt(index, value);
 			break;
+		}
+	case AbstractColumn::Text:
+		setTextAt(index, str);
+		break;
 
-		case AbstractColumn::DateTime:
-		case AbstractColumn::Month:
-		case AbstractColumn::Day:
-			QDateTime date_time = QDateTime::fromString(str,"yyyy-dd-MM hh:mm:ss:zzz");
-			setDateTimeAt(index, date_time);
-			break;
+	case AbstractColumn::DateTime:
+	case AbstractColumn::Month:
+	case AbstractColumn::Day:
+		QDateTime date_time = QDateTime::fromString(str,"yyyy-dd-MM hh:mm:ss:zzz");
+		setDateTimeAt(index, date_time);
+		break;
 	}
 
 	return true;
@@ -827,8 +903,7 @@ bool Column::isReadOnly() const {
  * by plots. The column mode specifies how to interpret
  * the values in the column additional to the data type.
  */
-AbstractColumn::ColumnMode Column::columnMode() const
-{
+AbstractColumn::ColumnMode Column::columnMode() const {
 	return m_column_private->columnMode();
 }
 
@@ -839,28 +914,25 @@ AbstractColumn::ColumnMode Column::columnMode() const
  * Rows beyond this can be masked etc. but should be ignored by filters,
  * plots etc.
  */
-int Column::rowCount() const
-{
+int Column::rowCount() const {
 	return m_column_private->rowCount();
 }
 
 /**
  * \brief Return the column plot designation
  */
-AbstractColumn::PlotDesignation Column::plotDesignation() const
-{
+AbstractColumn::PlotDesignation Column::plotDesignation() const {
 	return m_column_private->plotDesignation();
 }
 
-AbstractSimpleFilter * Column::outputFilter() const
-{
+AbstractSimpleFilter* Column::outputFilter() const {
 	return m_column_private->outputFilter();
 }
 
 /**
  * \brief Return a wrapper column object used for String I/O.
  */
-ColumnStringIO *Column::asStringColumn() const {
+ColumnStringIO* Column::asStringColumn() const {
 	return m_string_io;
 }
 
@@ -871,8 +943,7 @@ ColumnStringIO *Column::asStringColumn() const {
 /**
  * \brief Return the formula associated with row 'row'
  */
-QString Column::formula(int row) const
-{
+QString Column::formula(int row) const {
 	return m_column_private->formula(row);
 }
 
@@ -889,54 +960,38 @@ QString Column::formula(int row) const
  * 	list << QString(interval.toString() + ": " + my_column.formula(interval.start()));
  * \endcode
  */
-QList< Interval<int> > Column::formulaIntervals() const
-{
+QList< Interval<int> > Column::formulaIntervals() const {
 	return m_column_private->formulaIntervals();
 }
 
-void Column::handleFormatChange()
-{
+void Column::handleFormatChange() {
 	if (columnMode() == AbstractColumn::DateTime) {
-		String2DateTimeFilter *input_filter = static_cast<String2DateTimeFilter*>(m_column_private->inputFilter());
-		DateTime2StringFilter *output_filter = static_cast<DateTime2StringFilter*>(m_column_private->outputFilter());
+		String2DateTimeFilter* input_filter = static_cast<String2DateTimeFilter*>(m_column_private->inputFilter());
+		DateTime2StringFilter* output_filter = static_cast<DateTime2StringFilter*>(m_column_private->outputFilter());
 		input_filter->setFormat(output_filter->format());
 	}
 
 	emit aspectDescriptionChanged(this); // the icon for the type changed
 	if (!m_suppressDataChangedSignal)
 		emit dataChanged(this); // all cells must be repainted
-}
 
-
-QString Column::enumValueToString(int key, const QString& enum_name) {
-	int index = staticMetaObject.indexOfEnumerator(enum_name.toAscii());
-	if(index == -1) return QString("invalid");
-	QMetaEnum meta_enum = staticMetaObject.enumerator(index);
-	return QString(meta_enum.valueToKey(key));
-}
-
-int Column::enumStringToValue(const QString& string, const QString& enum_name) {
-	int index = staticMetaObject.indexOfEnumerator(enum_name.toAscii());
-	if(index == -1) return -1;
-	QMetaEnum meta_enum = staticMetaObject.enumerator(index);
-	return meta_enum.keyToValue(string.toAscii());
+	setStatisticsAvailable(false);
 }
 
 /**
  * \class ColumnStringIO
  * \brief String-IO interface of Column.
  */
-void ColumnStringIO::setTextAt(int row, const QString &value)
-{
+void ColumnStringIO::setTextAt(int row, const QString &value) {
 	m_setting = true;
 	m_to_set = value;
 	m_owner->copy(m_owner->m_column_private->inputFilter()->output(0), 0, row, 1);
 	m_setting = false;
 	m_to_set.clear();
+	m_owner->setStatisticsAvailable(false);
 }
 
-QString ColumnStringIO::textAt(int row) const
-{
+QString ColumnStringIO::textAt(int row) const {
 	if (m_setting)
 		return m_to_set;
 	else
