@@ -40,17 +40,14 @@
 
 #include <QPainter>
 #include <QMenu>
-#include <QDebug>
 #include <QTextDocument>
 #include <QGraphicsSceneContextMenuEvent>
-#include <QGraphicsSceneHoverEvent>
 
 #include "kdefrontend/GuiTools.h"
 #include <KConfigGroup>
 #include <QIcon>
 #include <KLocale>
 
-#include <cmath>
 #include <cfloat>
 
 /**
@@ -567,7 +564,6 @@ void Axis::setArrowPosition(ArrowPosition position) {
 		exec(new AxisSetArrowPositionCmd(d, position, i18n("%1: set arrow position")));
 }
 
-
 STD_SETTER_CMD_IMPL_F_S(Axis, SetArrowSize, float, arrowSize, retransformArrow);
 void Axis::setArrowSize(float arrowSize) {
 	Q_D(Axis);
@@ -828,7 +824,7 @@ void Axis::retransformTicks() {
 
 void Axis::majorTicksColumnAboutToBeRemoved(const AbstractAspect* aspect) {
 	Q_D(Axis);
-	if (aspect==d->majorTicksColumn) {
+	if (aspect == d->majorTicksColumn) {
 		d->majorTicksColumn = 0;
 		d->retransformTicks();
 	}
@@ -874,7 +870,7 @@ void Axis::visibilityChanged() {
 //#####################################################################
 //################### Private implementation ##########################
 //#####################################################################
-AxisPrivate::AxisPrivate(Axis *owner) : m_plot(0), m_cSystem(0), m_printing(false), m_hovered(false),
+AxisPrivate::AxisPrivate(Axis *owner) : m_plot(0), m_cSystem(0), m_printing(false), m_hovered(false), m_suppressRecalc(false),
 	majorTicksColumn(0), minorTicksColumn(0), gridItem(new AxisGrid(this)), q(owner) {
 
 	setFlag(QGraphicsItem::ItemIsSelectable, true);
@@ -912,11 +908,15 @@ void AxisPrivate::retransform() {
 	if (!m_plot)
 		return;
 
+	//TODO: add comment here for why we need this
 	m_cSystem = dynamic_cast<const CartesianCoordinateSystem*>(m_plot->coordinateSystem());
 	if (!m_cSystem)
 		return;
 
+	m_suppressRecalc = true;
 	retransformLine();
+	m_suppressRecalc = false;
+	recalcShapeAndBoundingRect();
 }
 
 void AxisPrivate::retransformLine() {
@@ -975,12 +975,12 @@ void AxisPrivate::retransformArrow() {
 		return;
 	}
 
-	if (arrowPosition==Axis::ArrowRight || arrowPosition==Axis::ArrowBoth) {
+	if (arrowPosition == Axis::ArrowRight || arrowPosition == Axis::ArrowBoth) {
 		const QPointF& endPoint = lines.at(lines.size()-1).p2();
 		this->addArrow(endPoint, 1);
 	}
 
-	if (arrowPosition==Axis::ArrowLeft || arrowPosition==Axis::ArrowBoth) {
+	if (arrowPosition == Axis::ArrowLeft || arrowPosition == Axis::ArrowBoth) {
 		const QPointF& endPoint = lines.at(0).p1();
 		this->addArrow(endPoint, -1);
 	}
@@ -991,8 +991,8 @@ void AxisPrivate::retransformArrow() {
 void AxisPrivate::addArrow(const QPointF& startPoint, int direction) {
 	static const float cos_phi = cos(3.14159/6);
 
-	if (orientation==Axis::AxisHorizontal) {
-		QPointF endPoint = QPointF(startPoint.x()+direction*arrowSize, startPoint.y());
+	if (orientation == Axis::AxisHorizontal) {
+		QPointF endPoint = QPointF(startPoint.x() + direction*arrowSize, startPoint.y());
 		arrowPath.moveTo(startPoint);
 		arrowPath.lineTo(endPoint);
 
@@ -1106,14 +1106,14 @@ void AxisPrivate::retransformTicks() {
 	minorTickPoints.clear();
 	tickLabelValues.clear();
 
-	if ( majorTicksNumber<1 || (majorTicksDirection == Axis::noTicks && minorTicksDirection == Axis::noTicks) ) {
+	if ( majorTicksNumber < 1 || (majorTicksDirection == Axis::noTicks && minorTicksDirection == Axis::noTicks) ) {
 		retransformTickLabelPositions(); //this calls recalcShapeAndBoundingRect()
 		return;
 	}
 
 	//determine the spacing for the major ticks
-	double majorTicksSpacing=0;
-	int tmpMajorTicksNumber=0;
+	double majorTicksSpacing = 0;
+	int tmpMajorTicksNumber = 0;
 	if (majorTicksType == Axis::TicksTotalNumber) {
 		//the total number of the major ticks is given - > determine the spacing
 		tmpMajorTicksNumber = majorTicksNumber;
@@ -1279,7 +1279,7 @@ void AxisPrivate::retransformTicks() {
 
 					//in the case a custom column is used for the minor ticks, we draw them _once_ for the whole range of the axis.
 					//execute the minor ticks loop only once.
-					if (iMajor>0)
+					if (iMajor > 0)
 						break;
 				}
 
@@ -1335,6 +1335,7 @@ void AxisPrivate::retransformTicks() {
 	(=the smallest possible number of float digits) precision for the floats
 */
 void AxisPrivate::retransformTickLabelStrings() {
+	DEBUG("AxisPrivate::retransformTickLabelStrings()");
 	if (labelsAutoPrecision) {
 		//check, whether we need to increase the current precision
 		int newPrecision = upperLabelsPrecision(labelsPrecision);
@@ -1350,45 +1351,46 @@ void AxisPrivate::retransformTickLabelStrings() {
 			}
 		}
 	}
+	DEBUG("labelsPrecision =" << labelsPrecision);
 
 	tickLabelStrings.clear();
 	QString str;
 	if (labelsFormat == Axis::FormatDecimal) {
 		QString nullStr = QString::number(0, 'f', labelsPrecision);
-		foreach(float value, tickLabelValues) {
+		foreach (float value, tickLabelValues) {
 			str = QString::number(value, 'f', labelsPrecision);
-			if (str == "-"+nullStr) str=nullStr;
+			if (str == "-" + nullStr) str = nullStr;
 			str = labelsPrefix + str + labelsSuffix;
 			tickLabelStrings << str;
 		}
 	} else if (labelsFormat == Axis::FormatScientificE) {
 		QString nullStr = QString::number(0, 'e', labelsPrecision);
-		foreach(float value, tickLabelValues) {
+		foreach (float value, tickLabelValues) {
 			str = QString::number(value, 'e', labelsPrecision);
-			if (str == "-"+nullStr) str=nullStr;
+			if (str == "-" + nullStr) str = nullStr;
 			tickLabelStrings << str;
 		}
 	} else if (labelsFormat == Axis::FormatPowers10) {
-		foreach(float value, tickLabelValues) {
-			str = "10<span style=\"vertical-align:super\">"+ QString::number(log10(value),'f',labelsPrecision)+"</span>";
+		foreach (float value, tickLabelValues) {
+			str = "10<span style=\"vertical-align:super\">" + QString::number(log10(value), 'f', labelsPrecision) + "</span>";
 			str = labelsPrefix + str + labelsSuffix;
 			tickLabelStrings << str;
 		}
 	} else if (labelsFormat == Axis::FormatPowers2) {
-		foreach(float value, tickLabelValues) {
-			str = "2<span style=\"vertical-align:super\">"+ QString::number(log2(value),'f',labelsPrecision)+"</span>";
+		foreach (float value, tickLabelValues) {
+			str = "2<span style=\"vertical-align:super\">" + QString::number(log2(value), 'f', labelsPrecision) + "</span>";
 			str = labelsPrefix + str + labelsSuffix;
 			tickLabelStrings << str;
 		}
 	} else if (labelsFormat == Axis::FormatPowersE) {
-		foreach(float value, tickLabelValues) {
-			str = "e<span style=\"vertical-align:super\">"+ QString::number(log(value),'f',labelsPrecision)+"</span>";
+		foreach (float value, tickLabelValues) {
+			str = "e<span style=\"vertical-align:super\">" + QString::number(log(value), 'f', labelsPrecision) + "</span>";
 			str = labelsPrefix + str + labelsSuffix;
 			tickLabelStrings << str;
 		}
 	} else if (labelsFormat == Axis::FormatMultipliesPi) {
-		foreach(float value, tickLabelValues) {
-			str = "<span>"+ QString::number(value / M_PI,'f',labelsPrecision)+"</span>" + QChar(0x03C0);
+		foreach (float value, tickLabelValues) {
+			str = "<span>" + QString::number(value / M_PI, 'f', labelsPrecision) + "</span>" + QChar(0x03C0);
 			str = labelsPrefix + str + labelsSuffix;
 			tickLabelStrings << str;
 		}
@@ -1399,28 +1401,29 @@ void AxisPrivate::retransformTickLabelStrings() {
 }
 
 /*!
-	returns the smalles upper limit for the precision
+	returns the smallest upper limit for the precision
 	where no duplicates for the tick label float occur.
  */
 int AxisPrivate::upperLabelsPrecision(int precision) {
+	DEBUG("AxisPrivate::upperLabelsPrecision() precision =" << precision);
 	//round float to the current precision and look for duplicates.
 	//if there are duplicates, increase the precision.
 	QList<float> tempValues;
-	for (int i=0; i<tickLabelValues.size(); ++i) {
+	for (int i = 0; i < tickLabelValues.size(); ++i) {
 		tempValues.append( round(tickLabelValues[i], precision) );
 	}
 
-	for (int i=0; i<tempValues.size(); ++i) {
-		for (int j=0; j<tempValues.size(); ++j) {
-			if (i==j) continue;
-			if ( AbstractCoordinateSystem::essentiallyEqual(tempValues.at(i), tempValues.at(j), pow(10,-precision)) ) {
+	for (int i = 0; i < tempValues.size(); ++i) {
+		for (int j = 0; j < tempValues.size(); ++j) {
+			if (i == j) continue;
+			if ( AbstractCoordinateSystem::essentiallyEqual(tempValues.at(i), tempValues.at(j), pow(10, -precision)) ) {
 				//duplicate for the current precision found, increase the precision and check again
-				return upperLabelsPrecision(precision+1);
+				return upperLabelsPrecision(precision + 1);
 			}
 		}
 	}
 
-	//no duplicates for the current precision found, return the current value
+	//no duplicates for the current precision found: return the current value
 	return precision;
 }
 
@@ -1429,20 +1432,21 @@ int AxisPrivate::upperLabelsPrecision(int precision) {
 	where no duplicates for the tick label float occur.
 */
 int AxisPrivate::lowerLabelsPrecision(int precision) {
+	DEBUG("AxisPrivate::lowerLabelsPrecision() precision =" << precision);
 	//round float to the current precision and look for duplicates.
 	//if there are duplicates, decrease the precision.
 	QList<float> tempValues;
-	for (int i=0; i<tickLabelValues.size(); ++i) {
+	for (int i = 0; i < tickLabelValues.size(); ++i) {
 		tempValues.append( round(tickLabelValues[i], precision-1) );
 	}
 
-	for (int i=0; i<tempValues.size(); ++i) {
-		for (int j=0; j<tempValues.size(); ++j) {
-			if (i==j) continue;
-			if ( AbstractCoordinateSystem::essentiallyEqual(tempValues.at(i), tempValues.at(j), pow(10,-precision)) ) {
+	for (int i = 0; i < tempValues.size(); ++i) {
+		for (int j = 0; j < tempValues.size(); ++j) {
+			if (i == j) continue;
+			if ( AbstractCoordinateSystem::essentiallyEqual(tempValues.at(i), tempValues.at(j), pow(10, -precision)) ) {
 				//duplicate found for the reduced precision
 				//-> current precision cannot be reduced, return the current value + 1
-				return precision+1;
+				return precision + 1;
 			}
 		}
 	}
@@ -1451,11 +1455,14 @@ int AxisPrivate::lowerLabelsPrecision(int precision) {
 	if (precision == 0)
 		return 0;
 	else
-		return lowerLabelsPrecision(precision-1);
+		return lowerLabelsPrecision(precision - 1);
 }
 
 double AxisPrivate::round(double value, int precision) {
-	return double(value*pow(10, precision))/pow(10, precision);
+	//DEBUG("AxisPrivate::round() value =" << value << "precision =" << precision);
+	double result = roundf(value * pow(10, precision)) / pow(10, precision);
+	//DEBUG("	result =" << result);
+	return result;
 }
 
 /*!
@@ -1545,7 +1552,7 @@ void AxisPrivate::retransformMajorGrid() {
 	//Currently, grid lines disappear somtimes without this flag
 	QList<QPointF> logicalMajorTickPoints = m_cSystem->mapSceneToLogical(majorTickPoints, AbstractCoordinateSystem::SuppressPageClipping);
 
-	if (!logicalMajorTickPoints.size())
+	if (logicalMajorTickPoints.isEmpty())
 		return;
 
 	//TODO:
@@ -1600,7 +1607,7 @@ void AxisPrivate::retransformMajorGrid() {
 		}
 	}
 
-	lines = m_cSystem->mapLogicalToScene(lines, AbstractCoordinateSystem::SuppressPageClipping | AbstractCoordinateSystem::MarkGaps);
+	lines = m_cSystem->mapLogicalToScene(lines, AbstractCoordinateSystem::SuppressPageClipping);
 	foreach (const QLineF& line, lines) {
 		majorGridPath.moveTo(line.p1());
 		majorGridPath.lineTo(line.p2());
@@ -1619,7 +1626,7 @@ void AxisPrivate::retransformMinorGrid() {
 	//minor tick points are already in scene coordinates, convert them back to logical...
 	//TODO: mapping should work without SuppressPageClipping-flag, check float comparisons in the map-function.
 	//Currently, grid lines disappear somtimes without this flag
-	QList<QPointF> logicalMinorTickPoints = m_cSystem->mapSceneToLogical(minorTickPoints, AbstractCoordinateSystem::SuppressPageClipping | AbstractCoordinateSystem::MarkGaps);
+	QList<QPointF> logicalMinorTickPoints = m_cSystem->mapSceneToLogical(minorTickPoints, AbstractCoordinateSystem::SuppressPageClipping);
 
 	QList<QLineF> lines;
 	if (orientation == Axis::AxisHorizontal) { //horizontal axis
@@ -1640,7 +1647,7 @@ void AxisPrivate::retransformMinorGrid() {
 		}
 	}
 
-	lines = m_cSystem->mapLogicalToScene(lines, AbstractCoordinateSystem::MarkGaps);
+	lines = m_cSystem->mapLogicalToScene(lines, AbstractCoordinateSystem::SuppressPageClipping);
 	foreach (const QLineF& line, lines) {
 		minorGridPath.moveTo(line.p1());
 		minorGridPath.lineTo(line.p2());
@@ -1650,6 +1657,9 @@ void AxisPrivate::retransformMinorGrid() {
 }
 
 void AxisPrivate::recalcShapeAndBoundingRect() {
+	if (m_suppressRecalc)
+		return;
+
 	prepareGeometryChange();
 
 	if (linePath.isEmpty()) {
@@ -1724,6 +1734,7 @@ void AxisPrivate::recalcShapeAndBoundingRect() {
 	\sa QGraphicsItem::paint()
  */
 void AxisPrivate::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget * widget) {
+	DEBUG("AxisPrivate::paint()");
 	Q_UNUSED(option)
 	Q_UNUSED(widget)
 
@@ -1768,7 +1779,7 @@ void AxisPrivate::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
 		painter->setFont(labelsFont);
 		QTextDocument td;
 		td.setDefaultFont(labelsFont);
-		for (int i=0; i<tickLabelPoints.size(); i++) {
+		for (int i = 0; i < tickLabelPoints.size(); i++) {
 			painter->translate(tickLabelPoints.at(i));
 			painter->save();
 			painter->rotate(-labelsRotationAngle);
@@ -1797,6 +1808,8 @@ void AxisPrivate::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
 		painter->setOpacity(q->selectedOpacity);
 		painter->drawPath(axisShape);
 	}
+
+	DEBUG("AxisPrivate::paint() DONE");
 }
 
 void AxisPrivate::contextMenuEvent(QGraphicsSceneContextMenuEvent* event) {
@@ -2206,3 +2219,91 @@ bool Axis::load(XmlStreamReader* reader) {
 
 	return true;
 }
+
+//##############################################################################
+//#########################  Theme management ##################################
+//##############################################################################
+void Axis::loadThemeConfig(const KConfig& config) {
+	const KConfigGroup group = config.group("Axis");
+
+	QPen p;
+	// Tick label
+	this->setLabelsColor(group.readEntry("LabelsFontColor",(QColor) this->labelsColor()));
+	this->setLabelsOpacity(group.readEntry("LabelsOpacity",this->labelsOpacity()));
+
+	//Line
+	this->setLineOpacity(group.readEntry("LineOpacity",this->lineOpacity()));
+	p.setColor(group.readEntry("LineColor", (QColor) this->linePen().color()));
+	p.setStyle((Qt::PenStyle)group.readEntry("LineStyle",(int) this->linePen().style()));
+	p.setWidthF(group.readEntry("LineWidth", this->linePen().widthF()));
+	this->setLinePen(p);
+
+	//Major ticks
+	this->setMajorGridOpacity(group.readEntry("MajorGridOpacity", this->majorGridOpacity()));
+	p.setColor(group.readEntry("MajorGridColor",(QColor) this->majorGridPen().color()));
+	p.setStyle((Qt::PenStyle)group.readEntry("MajorGridStyle",(int) this->majorGridPen().style()));
+	p.setWidthF(group.readEntry("MajorGridWidth", this->majorGridPen().widthF()));
+	this->setMajorGridPen(p);
+	p.setColor(group.readEntry("MajorTicksColor",(QColor)this->majorTicksPen().color()));
+	p.setStyle((Qt::PenStyle)group.readEntry("MajorTicksLineStyle",(int) this->majorTicksPen().style()));
+	p.setWidthF(group.readEntry("MajorTicksWidth", this->majorTicksPen().widthF()));
+	this->setMajorTicksPen(p);
+	this->setMajorTicksOpacity(group.readEntry("MajorTicksOpacity",this->majorTicksOpacity()));
+	this->setMajorTicksType((Axis::TicksType)group.readEntry("MajorTicksType",(int)this->majorTicksType()));
+
+	//Minor ticks
+	this->setMinorGridOpacity(group.readEntry("MinorGridOpacity", this->minorGridOpacity()));
+	p.setColor(group.readEntry("MinorGridColor",(QColor) this->minorGridPen().color()));
+	p.setStyle((Qt::PenStyle)group.readEntry("MinorGridStyle",(int) this->minorGridPen().style()));
+	p.setWidthF(group.readEntry("MinorGridWidth", this->minorGridPen().widthF()));
+	this->setMinorGridPen(p);
+	p.setColor(group.readEntry("MinorTicksColor",(QColor) this->minorTicksPen().color()));
+	p.setStyle((Qt::PenStyle)group.readEntry("MinorTicksLineStyle",(int) this->minorTicksPen().style()));
+	p.setWidthF(group.readEntry("MinorTicksWidth", this->minorTicksPen().widthF()));
+	this->setMinorTicksPen(p);
+	this->setMinorTicksOpacity(group.readEntry("MinorTicksOpacity",this->minorTicksOpacity()));
+	this->setMinorTicksType((Axis::TicksType)group.readEntry("MinorTicksType",(int)this->minorTicksType()));
+
+	const QList<TextLabel*>& childElements = children<TextLabel>(AbstractAspect::IncludeHidden);
+	foreach(TextLabel *child, childElements)
+		child->loadThemeConfig(config);
+}
+
+void Axis::saveThemeConfig(const KConfig& config) {
+	KConfigGroup group = config.group("Axis");
+
+	// Tick label
+	group.writeEntry("LabelsFontColor", (QColor) this->labelsColor());
+	group.writeEntry("LabelsOpacity", this->labelsOpacity());
+
+	//Line
+	group.writeEntry("LineOpacity", this->lineOpacity());
+	group.writeEntry("LineColor", (QColor) this->linePen().color());
+	group.writeEntry("LineStyle", (int) this->linePen().style());
+	group.writeEntry("LineWidth", this->linePen().widthF());
+
+	//Major ticks
+	group.writeEntry("MajorGridOpacity", this->majorGridOpacity());
+	group.writeEntry("MajorGridColor", (QColor) this->majorGridPen().color());
+	group.writeEntry("MajorGridStyle", (int) this->majorGridPen().style());
+	group.writeEntry("MajorGridWidth", this->majorGridPen().widthF());
+	group.writeEntry("MajorTicksColor", (QColor)this->majorTicksPen().color());
+	group.writeEntry("MajorTicksLineStyle", (int) this->majorTicksPen().style());
+	group.writeEntry("MajorTicksWidth", this->majorTicksPen().widthF());
+	group.writeEntry("MajorTicksOpacity", this->majorTicksOpacity());
+	group.writeEntry("MajorTicksType", (int)this->majorTicksType());
+
+	//Minor ticks
+	group.writeEntry("MinorGridOpacity", this->minorGridOpacity());
+	group.writeEntry("MinorGridColor",(QColor) this->minorGridPen().color());
+	group.writeEntry("MinorGridStyle", (int) this->minorGridPen().style());
+	group.writeEntry("MinorGridWidth", this->minorGridPen().widthF());
+	group.writeEntry("MinorTicksColor", (QColor) this->minorTicksPen().color());
+	group.writeEntry("MinorTicksLineStyle",( int) this->minorTicksPen().style());
+	group.writeEntry("MinorTicksWidth", this->minorTicksPen().widthF());
+	group.writeEntry("MinorTicksOpacity", this->minorTicksOpacity());
+	group.writeEntry("MinorTicksType", (int)this->minorTicksType());
+
+	const QList<TextLabel*>& childElements = children<TextLabel>(AbstractAspect::IncludeHidden);
+	childElements.at(0)->saveThemeConfig(config);
+}
